@@ -14,12 +14,13 @@
 #    under the License.
 
 import contextlib
+import io
 import socket
+from unittest import mock
 
-import mock
+import netaddr
 import netifaces
 from oslotest import base as test_base
-import six
 
 from oslo_utils import netutils
 
@@ -153,13 +154,52 @@ class NetworkUtilsTest(test_base.BaseTestCase):
         netutils.set_tcp_keepalive(mock_sock, False)
         self.assertEqual(1, len(mock_sock.mock_calls))
 
-    def test_is_valid_ipv4(self):
+    @mock.patch.object(netutils, 'LOG', autospec=True)
+    def test_is_valid_ipv4(self, mock_log):
+        expected_log = 'Converting in non strict mode is deprecated. ' \
+            'You should pass strict=False if you want to preserve ' \
+            'legacy behavior'
         self.assertTrue(netutils.is_valid_ipv4('42.42.42.42'))
 
         self.assertFalse(netutils.is_valid_ipv4('-1.11.11.11'))
 
         self.assertFalse(netutils.is_valid_ipv4(''))
 
+        self.assertTrue(netutils.is_valid_ipv4('10'))
+        mock_log.warn.assert_called_with(expected_log)
+        mock_log.reset_mock()
+        self.assertTrue(netutils.is_valid_ipv4('10.10'))
+        mock_log.warn.assert_called_with(expected_log)
+        mock_log.reset_mock()
+        self.assertTrue(netutils.is_valid_ipv4('10.10.10'))
+        mock_log.warn.assert_called_with(expected_log)
+        mock_log.reset_mock()
+        self.assertTrue(netutils.is_valid_ipv4('10.10.10.10'))
+        mock_log.warn.assert_not_called()
+        mock_log.reset_mock()
+        self.assertFalse(
+            netutils.is_valid_ipv4('10', strict=True)
+        )
+        self.assertFalse(
+            netutils.is_valid_ipv4('10.10', strict=True)
+        )
+        self.assertFalse(
+            netutils.is_valid_ipv4('10.10.10', strict=True)
+        )
+        mock_log.warn.assert_not_called()
+        mock_log.reset_mock()
+        self.assertTrue(
+            netutils.is_valid_ipv4('10', strict=False)
+        )
+        self.assertTrue(
+            netutils.is_valid_ipv4('10.10', strict=False)
+        )
+        self.assertTrue(
+            netutils.is_valid_ipv4('10.10.10', strict=False)
+        )
+        mock_log.warn.assert_not_called()
+        mock_log.reset_mock()
+
     def test_is_valid_ipv6(self):
         self.assertTrue(netutils.is_valid_ipv6('::1'))
 
@@ -357,10 +397,42 @@ class IPv6byEUI64TestCase(test_base.BaseTestCase):
                           netutils.get_ipv6_addr_by_EUI64(prefix, mac))
 
 
+class MACbyIPv6TestCase(test_base.BaseTestCase):
+    """Unit tests to extract MAC from IPv6."""
+
+    def test_reverse_generate_IPv6_by_EUI64(self):
+        self.assertEqual(
+            netaddr.EUI('00:16:3e:33:44:55'),
+            netutils.get_mac_addr_by_ipv6(
+                netaddr.IPAddress('2001:db8::216:3eff:fe33:4455')),
+        )
+
+    def test_random_qemu_mac(self):
+        self.assertEqual(
+            netaddr.EUI('52:54:00:42:02:19'),
+            netutils.get_mac_addr_by_ipv6(
+                netaddr.IPAddress('fe80::5054:ff:fe42:219')),
+        )
+
+    def test_local(self):
+        self.assertEqual(
+            netaddr.EUI('02:00:00:00:00:00'),
+            netutils.get_mac_addr_by_ipv6(
+                netaddr.IPAddress('fe80::ff:fe00:0')),
+        )
+
+    def test_universal(self):
+        self.assertEqual(
+            netaddr.EUI('00:00:00:00:00:00'),
+            netutils.get_mac_addr_by_ipv6(
+                netaddr.IPAddress('fe80::200:ff:fe00:0')),
+        )
+
+
 @contextlib.contextmanager
 def mock_file_content(content):
     # Allows StringIO to act like a context manager-enabled file.
-    yield six.StringIO(content)
+    yield io.StringIO(content)
 
 
 class TestIsIPv6Enabled(test_base.BaseTestCase):
@@ -374,19 +446,19 @@ class TestIsIPv6Enabled(test_base.BaseTestCase):
         self.addCleanup(reset_detection_flag)
 
     @mock.patch('os.path.exists', return_value=True)
-    @mock.patch('six.moves.builtins.open', return_value=mock_file_content('0'))
+    @mock.patch('builtins.open', return_value=mock_file_content('0'))
     def test_enabled(self, mock_open, exists):
         enabled = netutils.is_ipv6_enabled()
         self.assertTrue(enabled)
 
     @mock.patch('os.path.exists', return_value=True)
-    @mock.patch('six.moves.builtins.open', return_value=mock_file_content('1'))
+    @mock.patch('builtins.open', return_value=mock_file_content('1'))
     def test_disabled(self, mock_open, exists):
         enabled = netutils.is_ipv6_enabled()
         self.assertFalse(enabled)
 
     @mock.patch('os.path.exists', return_value=False)
-    @mock.patch('six.moves.builtins.open',
+    @mock.patch('builtins.open',
                 side_effect=AssertionError('should not read'))
     def test_disabled_non_exists(self, mock_open, exists):
         enabled = netutils.is_ipv6_enabled()
@@ -396,14 +468,14 @@ class TestIsIPv6Enabled(test_base.BaseTestCase):
     def test_memoize_enabled(self, exists):
         # Reset the flag to appear that we haven't looked for it yet.
         netutils._IS_IPV6_ENABLED = None
-        with mock.patch('six.moves.builtins.open',
+        with mock.patch('builtins.open',
                         return_value=mock_file_content('0')) as mock_open:
             enabled = netutils.is_ipv6_enabled()
             self.assertTrue(mock_open.called)
             self.assertTrue(netutils._IS_IPV6_ENABLED)
             self.assertTrue(enabled)
         # The second call should not use open again
-        with mock.patch('six.moves.builtins.open',
+        with mock.patch('builtins.open',
                         side_effect=AssertionError('should not be called')):
             enabled = netutils.is_ipv6_enabled()
             self.assertTrue(enabled)
@@ -412,18 +484,18 @@ class TestIsIPv6Enabled(test_base.BaseTestCase):
     def test_memoize_disabled(self, exists):
         # Reset the flag to appear that we haven't looked for it yet.
         netutils._IS_IPV6_ENABLED = None
-        with mock.patch('six.moves.builtins.open',
+        with mock.patch('builtins.open',
                         return_value=mock_file_content('1')):
             enabled = netutils.is_ipv6_enabled()
             self.assertFalse(enabled)
         # The second call should not use open again
-        with mock.patch('six.moves.builtins.open',
+        with mock.patch('builtins.open',
                         side_effect=AssertionError('should not be called')):
             enabled = netutils.is_ipv6_enabled()
             self.assertFalse(enabled)
 
     @mock.patch('os.path.exists', return_value=False)
-    @mock.patch('six.moves.builtins.open',
+    @mock.patch('builtins.open',
                 side_effect=AssertionError('should not read'))
     def test_memoize_not_exists(self, mock_open, exists):
         # Reset the flag to appear that we haven't looked for it yet.
